=======
NetView
=======

NetView is a simple Django app.

Detailed documentation is in... Submission readme

Quick start
-----------

1. Install NetView:: 

    pip install NetView

2. Run Server::

    initmigrate
    runmyserver

3. Access Application:: 

    http://127.0.0.1:8000/ (default)
